%bcond_with pcre
%bcond_with python

%define lib_major	0
%define lib_api 	3.7.2
%define lib_name	%mklibname %{name} %{lib_api} %{lib_major}
%define dev_name	%mklibname %{name} -d

%define script_version 0.3

Name:		ganglia
License:	BSD
Version:	3.7.2
Release:	%mkrel 10
Group:		Monitoring
Summary:	Cluster Toolkit
URL:		https://ganglia.sourceforge.net/
Source:		https://downloads.sourceforge.net/ganglia/%{name}-%{version}.tar.gz
Requires(post):	rpm-helper
Requires(preun): rpm-helper
#Source1:	gmond.conf
Source2:	%{name}-monitor-script-%{script_version}.tar.bz2
Source3:	%{name}-monitor-script.d
Source4:	ganglia-script
Source5:	README.script
Source6:	ganglia-monitor-logrotate.d
Source7:	gmond.service
Source8:	gmetad.service
Patch3:         ganglia-3.7.2-tirpc-hack.patch
Patch4:         ganglia-3.7.2-gcc14-cast.patch
%if %{with pcre}
BuildRequires:	pkgconfig(libpcre)
%endif
BuildRequires:	rpcgen
BuildRequires:	libtirpc-devel
BuildRequires:	pkgconfig(apr-1)
BuildRequires:	pkgconfig(libconfuse)
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	gettext-devel
%if %{with python}
BuildRequires:	pkgconfig(python3)
%endif
BuildRequires:	pkgconfig(librrd)

%description
Ganglia is a scalable, real-time cluster monitoring and execution environment
with all execution requests and cluster statistics expressed in an open
well-defined XML format.

%package 	core
Group:		Monitoring
Summary:	Cluster Core
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description	core
The core package of Ganglia Monitor.

%package	gmetad
Group:		Monitoring
Summary:	Meta daemon
Requires(post): rpm-helper
Requires(preun): rpm-helper
Requires:	%name-core = %{version}-%{release}

%description gmetad
Ganglia is a scalable, real-time monitoring and execution environment
with all execution requests and statistics expressed in an open
well-defined XML format.

This gmetad daemon can aggregate monitoring data from several clusters
to form a monitoring grid. It also keeps metric history using the RRD tool.

%package	-n %{dev_name}
Group:		Development/Other
Summary:	Cluster Toolkit Library
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{lib_name} = %{version}-%{release}
Conflicts:	%{lib_name} < 3.1.7-3
Obsoletes:	%{_lib}ganglia1-devel < 3.6.0-2
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description 	-n %{dev_name}
The Ganglia Monitoring Core library provides a set of
functions that programmers can use to build scalable
cluster or grid applications.

%package 	-n %{lib_name}
Group:		Development/Other
Summary:	Cluster Toolkit Library
Provides:	lib%name = %{version}-%{release}
# Obsolete old wrongly named lib for smooth upgrades
Obsoletes:	%{_lib}ganglia1 < 3.6.0-2
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description	-n %{lib_name}
The Ganglia Monitoring Core library provides a set of
functions that programmers can use to build scalable
cluster or grid applications.

%package	script
Group:		Monitoring
Summary:	Cluster Script
Provides:	%{name}-script = %{version}-%{release}
Requires:	%{name}-core
Requires(post): rpm-helper
Requires(preun): rpm-helper

%description	script
Ganglia Monitor Script is an extrension for Ganglia Monitor.
It's a easy way to add value to monitor for your
Ganglia Monitor.

%prep
%setup -q -T -n %{name}-monitor-script-%{script_version} -b 2
%setup -q -T -n %{name}-%{version} -b 0
%patch -P 3 -p1
%patch -P 4 -p1

%build
touch Makefile.am
aclocal -I m4
autoheader
automake --add-missing --copy --foreign 2>/dev/null
libtoolize --automake --copy
automake --add-missing --copy --foreign
autoconf -f || exit 1
%configure \
%if %{without pcre}
	-with-libpcre=no \
%endif
%if %{without python}
	--disable-python \
%endif
	--disable-static \
	--with-gmetad \
	--enable-status
%__make


%install
mkdir -p %{buildroot}/var/lib/ganglia/rrds

%make_install

install -D -m 644 %{SOURCE7} %{buildroot}%{_unitdir}/gmond.service
install -D -m 644 %{SOURCE8} %{buildroot}%{_unitdir}/gmetad.service

#Disabling setuid
echo "setuid off" >> %{_builddir}/%{name}-%{version}/gmetad/gmetad.conf

install -D -m 755 %{SOURCE4} %{buildroot}%{_bindir}

#script
mkdir -p %{buildroot}%{_datadir}/%{name}-script/script/
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}-script-%{version}/
install %{_builddir}/%{name}-monitor-script-%{script_version}/* %{buildroot}%{_datadir}/%{name}-script/script/
install %{SOURCE5} %{buildroot}%{_defaultdocdir}/%{name}-script-%{version}/README

install -D -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/ganglia-monitor-core

%{_builddir}/%{name}-%{version}/gmond/gmond -t > %{buildroot}%{_sysconfdir}/gmond.conf
perl -pi -e 's|name = "unspecified".*|name = "Cluster"|' %{buildroot}%{_sysconfdir}/gmond.conf

%multiarch_binaries %{buildroot}%{_bindir}/ganglia-config

#we don't want these
find %{buildroot} -name "*.la" -delete

#core
%post core
%_post_service gmond

%preun core
%_preun_service gmond

#script
%post script
%_post_service ganglia-script

%preun script
%_preun_service ganglia-script

%post gmetad
%_post_service gmetad
if [ -d "var/lib/ganglia/rrds" ]; then
	echo "gmetad is launched as the nobody user now, changing /var/lib/ganglia/rrds permissions to nobody:nogroup"
	chown -R nobody:nogroup /var/lib/ganglia/rrds
fi

%preun gmetad
%_preun_service gmetad

%files gmetad
%attr(0777,nobody,nogroup) /var/lib/ganglia/rrds
%{_sbindir}/gmetad
%{_unitdir}/gmetad.service
%if %{with python}
%config(noreplace) %{_sysconfdir}/conf.d/modpython.conf
%endif
%config(noreplace) %{_sysconfdir}/gmetad.conf
%{_mandir}/man1/gmetad.1*
%{_mandir}/man1/gmetad.py.1*

%files core
%doc README AUTHORS COPYING gmond/gmond.conf.html
%{_bindir}/gmetric
%{_bindir}/gstat
%multiarch %{multiarch_bindir}/ganglia-config
%{_bindir}/ganglia-config
%{_sbindir}/gmond
%{_unitdir}/gmond.service
%config(noreplace) %{_sysconfdir}/gmond.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/ganglia-monitor-core
%{_mandir}/man1/gmetric.1*
%{_mandir}/man1/gmond.1*
%{_mandir}/man1/gstat.1*
%{_mandir}/man5/gmond.conf.5*

%files -n %{lib_name}
%doc README AUTHORS COPYING
%{_libdir}/libganglia.so.*
%{_libdir}/ganglia/*.so

%files -n %{dev_name}
%doc README AUTHORS COPYING
%{_includedir}/*
%{_libdir}/libganglia.so

%files script
%{_bindir}/ganglia-script
%{_datadir}/%{name}-script
%doc %{_defaultdocdir}/%{name}-script-%{version}/README


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 3.7.2-10.mga10
+ Revision: 2229027
- Mageia 10 Mass Rebuild

* Thu Oct 17 2024 ns80 <ns80> 3.7.2-9.mga10
+ Revision: 2107761
- add a patch from Fedora to try to fix building with GCC 14

* Thu Apr 13 2023 daviddavid <daviddavid> 3.7.2-8.mga9
+ Revision: 1952900
- disable old pcre support in Mageia 9 (mga#31791)

* Fri Nov 11 2022 solbu <solbu> 3.7.2-7.mga9
+ Revision: 1905760
- Fix indentation
- Fix missing dependency

* Fri Apr 01 2022 umeabot <umeabot> 3.7.2-6.mga9
+ Revision: 1838540
- Mageia 9 Mass Rebuild
+ tv <tv>
- BR rpcgen

* Thu Nov 26 2020 tv <tv> 3.7.2-5.mga8
+ Revision: 1649473
- fix building with libtirpc

* Mon Feb 24 2020 daviddavid <daviddavid> 3.7.2-4.mga8
+ Revision: 1550136
- disable python support until a python3 port
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Sun Sep 23 2018 umeabot <umeabot> 3.7.2-3.mga7
+ Revision: 1297821
- Mageia 7 Mass Rebuild

* Thu Dec 28 2017 wally <wally> 3.7.2-2.mga7
+ Revision: 1186595
- rebuild for new libconfuse

* Tue Oct 03 2017 solbu <solbu> 3.7.2-1.mga7
+ Revision: 1168020
- Drop invalid ChangeLog
- The lib .so-name changed, update spec
- New version: 3.7.2

* Fri May 06 2016 luigiwalser <luigiwalser> 3.6.0-7.mga6
+ Revision: 1010062
- rebuild for rrdtool

* Thu Feb 04 2016 umeabot <umeabot> 3.6.0-6.mga6
+ Revision: 934466
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.6.0-5.mga5
+ Revision: 746577
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.6.0-4.mga5
+ Revision: 679408
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 3.6.0-3.mga4
+ Revision: 532582
- Mageia 4 Mass Rebuild

* Wed Aug 21 2013 wally <wally> 3.6.0-2.mga4
+ Revision: 468825
- fix lib and devel pkg names
- disable static build and drop .la files
- clean .spec a bit

* Thu May 30 2013 solbu <solbu> 3.6.0-1.mga4
+ Revision: 433456
- New version

* Fri Jan 11 2013 umeabot <umeabot> 3.5.0-3.mga3
+ Revision: 351046
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ solbu <solbu>
- Don't ship INSTALL file

* Thu Dec 20 2012 solbu <solbu> 3.5.0-1.mga3
+ Revision: 333494
- New version

* Sat Dec 01 2012 fwang <fwang> 3.4.0-2.mga3
+ Revision: 323774
- rebuild for new pcre

* Tue Aug 14 2012 guillomovitch <guillomovitch> 3.4.0-1.mga3
+ Revision: 281295
- new version
- systemd support
- spec cleanup
- ship gmond man pages in gmond package
- drop webfronted package, no more included in the distribution

* Sun Apr 29 2012 colin <colin> 3.1.7-7.mga2
+ Revision: 234273
- Add LSB headers to initscripts (mga#5262)

* Mon Apr 02 2012 pterjan <pterjan> 3.1.7-6.mga2
+ Revision: 227778
- Rebuild after libexpat.la removal

* Tue Apr 05 2011 misc <misc> 3.1.7-5.mga1
+ Revision: 80780
- fix and clean requires of webfrontend subpackages

* Tue Feb 08 2011 ennael <ennael> 3.1.7-4.mga1
+ Revision: 49112
- remove mdk version
- imported package ganglia


* Thu Dec 02 2010 Paulo Andrade <pcpa@mandriva.com.br> 3.1.7-4mdv2011.0
+ Revision: 605290
- Rebuild with apr with workaround to issue with gcc type based

* Mon Oct 18 2010 Funda Wang <fwang@mandriva.org> 3.1.7-3mdv2011.0
+ Revision: 586587
- fix pacakge file list

* Mon Apr 26 2010 Antoine Ginies <aginies@mandriva.com> 3.1.7-2mdv2010.1
+ Revision: 539043
- fix bump release, fix gmond script (bad path to gmond.conf file)
- fix path to gmond.conf file
- version 3.1.7, fix summary, move ganglia conf in /etc/, now gmetad is launched as nobody user (fix some perms)

* Tue Dec 15 2009 Antoine Ginies <aginies@mandriva.com> 3.1.2-4mdv2010.1
+ Revision: 478979
- bump to release 4

* Tue Dec 15 2009 Antoine Ginies <aginies@mandriva.com> 3.1.2-2mdv2010.1
+ Revision: 478816
- fix ganglia hang, (#56428 thx J.A. Magallon)

* Tue Jun 23 2009 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.2-1mdv2010.0
+ Revision: 388671
- new version
- rediff format patch

* Sun Jan 04 2009 Jérôme Soyer <saispo@mandriva.org> 3.1.1-1mdv2009.1
+ Revision: 324719
- New upstream release

* Sat Sep 20 2008 Oden Eriksson <oeriksson@mandriva.com> 3.1.0-2mdv2009.0
+ Revision: 286183
- fix deps

  + Antoine Ginies <aginies@mandriva.com>
    - fix initscript and path to configurations files
    - fix path to so lib
    - new gmetad initscript, new release 3.1.0
    - fix initscript

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - fix no-buildroot-tag

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue Feb 12 2008 Antoine Ginies <aginies@mandriva.com> 3.0.6-1mdv2008.1
+ Revision: 165772
- new source
- new release

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request


* Wed Jan 17 2007 Erwan Velu <erwan@mandriva.org> 3.0.4-1mdv2007.0
+ Revision: 109923
- 3.0.4
  Removing unecessary patch0 & patch1
- Import ganglia

* Wed Aug 09 2006 Antoine Ginies <aginies@mandriva.com> 3.0.3-1mdv2007.0
- 3.0.3 release

* Thu Jul 06 2006 Thierry Vignaud <tvignaud@mandriva.com> 3.0.2-2mdv2007.0
- fix group

* Mon Apr 24 2006 Nicolas Lécureuil <neoclust@mandriva.org> 3.0.2-2mdk
- Add BuildRequires
- Fix PreReq

* Thu Nov 17 2005 Antoine Ginies <aginies@n2.mandriva.com> 3.0.2-1mdk
- 3.0.2 release

* Wed Mar 30 2005 Antoine Ginies <aginies@n1.mandrakesoft.com> 3.0.1-1mdk
- serious bugs fixed in 3.0.1 release: 
    gmond Unicast Communication Bug Fixed
    gmond.conf Conversion Bug Fixed
    Network Metrics Bug Fixed for Linux 2.6.x Kernels
- use noarch (ganglia-webfrontend)

* Fri Mar 25 2005 Eskild Hustvedt <eskild@mandrake.org> 3.0.0-5mdk
- Fixed group of ganglia-webfrontend
- %%mkrel

* Tue Mar 22 2005 Antoine Ginies <aginies@n1.mandrakesoft.com> 3.0.0-4mdk
- fix service for ganglia-script

* Sat Mar 19 2005 Antoine Ginies <aginies@n1.mandrakesoft.com> 3.0.0-3mdk
- use gmond -t to create a default configuration file

* Sat Mar 19 2005 Antoine Ginies <aginies@mandrakesoft.com> 3.0.0-2mdk
- fix requires and use Ganglia 3.0.0 web pages (thx J.A. Magallon report)
- add gmond.conf.html in ganglia-core package

* Thu Mar 17 2005 Antoine Ginies <aginies@mandrakesoft.com> 3.0.0 -1mdk
- new release 3.0.0
- use

* Fri Oct 29 2004 Erwan Velu <erwan@mandrakesoft.com> 2.5.7-1mdk
- 2.5.7

* Fri Jun 18 2004 Erwan Velu <erwan@mandrakesoft.com> 2.5.6-2mdk
- Fixing segfault when gmond is not started

* Tue Apr 06 2004 Erwan Velu <erwan@mandrakesoft.com> 2.5.6-1mdk
- New release
- Remove patch0

* Thu Feb 26 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 2.5.4-2mdk
- Fix DIRM (distlint)
- %%mklibname
- patch2: fix DESTDIR
- cleanup, cleanup, cleanup... /me slaps Erwan and Aginies :)
 Tue Aug 19 2003 Erwan Velu <erwan@mandrakesoft.com> 2.5.4-1mdk
- 2.5.4

